package com.jz.dmp.modules.controller.sys;

import javax.servlet.http.HttpServletRequest;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import com.jz.common.bean.BaseBeanResponse;
import com.jz.common.bean.BaseResponse;
import com.jz.common.bean.PageInfoResponse;
import com.jz.common.constant.StatuConstant;
import com.jz.dmp.modules.controller.sys.bean.DmpRoleBatch;
import com.jz.dmp.modules.controller.sys.bean.DmpRoleDto;
import com.jz.dmp.modules.controller.sys.bean.DmpRoleRequest;
import com.jz.dmp.modules.model.DmpRole;
import com.jz.dmp.modules.service.sys.DmpRoleService;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;

/**
 * 角色表Controller
 * @author ybz
 *
 */
@RestController
@RequestMapping("/dmp/role")
@Api(tags = "角色表")
public class DmpRoleController {
	
	@Autowired
	private DmpRoleService dmpRoleService;
	
	/**列表查询角色表
	 * @param dmpRoleRequest
	 * @return
	 */
	//@RequestMapping(method = RequestMethod.POST, value = "/findListWithPage")
	//@ApiOperation(value = "分頁列表查询角色表", notes = "分頁列表查询角色表")
	public PageInfoResponse<DmpRoleDto> findListWithPage(@RequestBody DmpRoleRequest dmpRoleRequest, HttpServletRequest httpRequest){
		PageInfoResponse<DmpRoleDto> pageInfo = new PageInfoResponse<DmpRoleDto>();
		try {
			pageInfo = dmpRoleService.findListWithPage(dmpRoleRequest, httpRequest);
		} catch (Exception e) {
			pageInfo.setMessage("查询失败");
			pageInfo.setCode(StatuConstant.FAILURE_CODE);
			e.printStackTrace();
		}
		
		return pageInfo;
	}
	
	/**列表查询角色表
	 * @param dmpRoleRequest
	 * @return
	 */
	@RequestMapping(method = RequestMethod.POST, value = "/findList")
	@ApiOperation(value = "列表查询角色表", notes = "列表查询角色表")
	public BaseBeanResponse<DmpRoleDto> findList(@RequestBody DmpRoleRequest dmpRoleRequest, HttpServletRequest httpRequest){
		BaseBeanResponse<DmpRoleDto> baseBeanResponse = new BaseBeanResponse<DmpRoleDto>();
		try {
			baseBeanResponse = dmpRoleService.findList(dmpRoleRequest, httpRequest);
		} catch (Exception e) {
			baseBeanResponse.setMessage("查询失败");
			baseBeanResponse.setCode(StatuConstant.FAILURE_CODE);
			e.printStackTrace();
		}
		
		return baseBeanResponse;
	}
	
	
	/**主键查询角色表
	 * @param dmpRoleRequest
	 * @return
	 */
	//@RequestMapping(method = RequestMethod.POST, value = "/view")
	//@ApiOperation(value = "主键查询角色表", notes = "主键查询角色表")
	//@ApiImplicitParam(name = "roleId", value = "角色表主键")
	public BaseBeanResponse<DmpRoleDto> view(@RequestParam(name = "roleId", required = true ) Integer roleId, HttpServletRequest httpRequest){
		BaseBeanResponse<DmpRoleDto> baseBeanResponse = new BaseBeanResponse<DmpRoleDto>();
		try {
			baseBeanResponse = dmpRoleService.findById(roleId, httpRequest);
		} catch (Exception e) {
			baseBeanResponse.setMessage("请求失败");
			baseBeanResponse.setCode(StatuConstant.FAILURE_CODE);
			e.printStackTrace();
		}
		
		return baseBeanResponse;
	}
	
	/**删除角色表
	 * @param roleId
	 * @return
	 */
	//@RequestMapping(method = RequestMethod.POST, value = "/delete")
	//@ApiOperation(value = "删除角色表", notes = "删除角色表")
	//@ApiImplicitParam(name = "roleId", value = "角色表主键")
	public BaseResponse delete(@RequestParam(name = "roleId", required = true ) Integer roleId, HttpServletRequest httpRequest){
		BaseResponse baseResponse = new BaseResponse();
		try {
			baseResponse = dmpRoleService.deleteById(roleId, httpRequest);
		} catch (Exception e) {
			baseResponse.setMessage("删除失败");
			baseResponse.setCode(StatuConstant.FAILURE_CODE);
			e.printStackTrace();
		}
		
		return baseResponse;
	}
	
	/**软删除角色表
	 * @param roleId
	 * @return
	 */
	//@RequestMapping(method = RequestMethod.POST, value = "/softDelete")
	//@ApiOperation(value = "软删除角色表", notes = "软删除角色表")
	//@ApiImplicitParam(name = "roleId", value = "角色表主键")
	public BaseResponse softDelete(@RequestParam(name = "roleId", required = true ) Integer roleId, HttpServletRequest httpRequest){
		BaseResponse baseResponse = new BaseResponse();
		try {
			baseResponse = dmpRoleService.softDeleteById(roleId, httpRequest);
		} catch (Exception e) {
			baseResponse.setMessage("软删除失败");
			baseResponse.setCode(StatuConstant.FAILURE_CODE);
			e.printStackTrace();
		}
		
		return baseResponse;
	}
	
	/**新增角色表
	 * @param dmpRoleRequest
	 * @return
	 */
	//@RequestMapping(method = RequestMethod.POST, value = "/add")
	//@ApiOperation(value = "新增角色表", notes = "新增角色表")
	public BaseBeanResponse<DmpRole> add(@RequestBody DmpRole dmpRole, HttpServletRequest httpRequest){
		BaseBeanResponse<DmpRole> baseBeanResponse = new BaseBeanResponse<DmpRole>();
		try {
			baseBeanResponse = dmpRoleService.add(dmpRole, httpRequest);
		} catch (Exception e) {
			baseBeanResponse.setMessage("新增失败");
			baseBeanResponse.setCode(StatuConstant.FAILURE_CODE);
			e.printStackTrace();
		}
		
		return baseBeanResponse;
	}
	
	/**批量新增角色表
	 * @param dmpRoleRequest
	 * @return
	 */
	//@RequestMapping(method = RequestMethod.POST, value = "/addBatch")
	//@ApiOperation(value = "批量新增角色表", notes = "批量新增角色表")
	public BaseBeanResponse<DmpRoleBatch> addBatch(@RequestBody DmpRoleBatch dmpRoleBatch, HttpServletRequest httpRequest){
		BaseBeanResponse<DmpRoleBatch> baseBeanResponse = new BaseBeanResponse<DmpRoleBatch>();
		try {
			baseBeanResponse = dmpRoleService.addBatch(dmpRoleBatch, httpRequest);
		} catch (Exception e) {
			baseBeanResponse.setMessage("批量新增失败");
			baseBeanResponse.setCode(StatuConstant.FAILURE_CODE);
			e.printStackTrace();
		}
		
		return baseBeanResponse;
	}
	
	/**修改角色表
	 * @param dmpRoleRequest
	 * @return
	 */
	//@RequestMapping(method = RequestMethod.POST, value = "/edit")
	//@ApiOperation(value = "修改角色表", notes = "修改角色表")
	public BaseBeanResponse<DmpRole> edit(@RequestBody DmpRole dmpRole, HttpServletRequest httpRequest){
		BaseBeanResponse<DmpRole> baseBeanResponse = new BaseBeanResponse<DmpRole>();
		try {
			baseBeanResponse = dmpRoleService.edit(dmpRole, httpRequest);
		} catch (Exception e) {
			baseBeanResponse.setMessage("修改失败");
			baseBeanResponse.setCode(StatuConstant.FAILURE_CODE);
			e.printStackTrace();
		}
		
		return baseBeanResponse;
	}
	
}
