package com.jz.dmp.modules.service.sys.impl;

import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

import javax.servlet.http.HttpServletRequest;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.CollectionUtils;

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.jz.common.bean.BaseBeanResponse;
import com.jz.common.bean.BaseResponse;
import com.jz.common.bean.PageInfoResponse;
import com.jz.common.constant.Constants;
import com.jz.common.constant.ResultCode;
import com.jz.common.persistence.BaseService;
import com.jz.dmp.modules.controller.sys.bean.DmpRolePermissionBatch;
import com.jz.dmp.modules.controller.sys.bean.DmpRolePermissionDto;
import com.jz.dmp.modules.controller.sys.bean.DmpRolePermissionRequest;
import com.jz.dmp.modules.dao.sys.DmpRolePermissionMapper;
import com.jz.dmp.modules.model.DmpRolePermission;
import com.jz.dmp.modules.service.sys.DmpRolePermissionService;

/**
 * 角色资源关系表服务的实现?
 * @author ybz
 *
 */
@Service("dmpRolePermissionService")
public class DmpRolePermissionServiceImpl extends BaseService implements DmpRolePermissionService {
	
	private static Logger logger = LoggerFactory.getLogger(DmpRolePermissionServiceImpl.class);
	
	@Autowired
	private DmpRolePermissionMapper dmpRolePermissionMapper;

	/* (non-Javadoc)
	 * @see com.ycxc.vmts.service.DmpRolePermissionService#findList(com.ycxc.vmts.controller.bean.DmpRolePermissionRequest, javax.servlet.http.HttpServletRequest)
	 */
	@Override
	public PageInfoResponse<DmpRolePermissionDto> findList(DmpRolePermissionRequest dmpRolePermissionRequest, HttpServletRequest httpRequest)
			throws Exception {
		PageInfoResponse<DmpRolePermissionDto> pageInfoResponse = new PageInfoResponse<>();
		
		Map<String, Object> param = new HashMap<>();
		//主键
		if (dmpRolePermissionRequest.getRolePermissionId() != null) {
			param.put("rolePermissionId", dmpRolePermissionRequest.getRolePermissionId());
		}
		//角色ID
		if (dmpRolePermissionRequest.getRoleId() != null) {
			param.put("roleId", dmpRolePermissionRequest.getRoleId());
		}
		//资源ID
		if (dmpRolePermissionRequest.getPermissionId() != null) {
			param.put("permissionId", dmpRolePermissionRequest.getPermissionId());
		}
		
		PageHelper.startPage(dmpRolePermissionRequest.getPageNum(), dmpRolePermissionRequest.getPageSize());
		List<DmpRolePermissionDto> list = dmpRolePermissionMapper.findList(param);
		PageInfo<DmpRolePermissionDto> pageInfo = new PageInfo<>(list);
		
		pageInfoResponse.setCode(ResultCode.SUCCESS.val());
		pageInfoResponse.setMessage("查询成功");
		pageInfoResponse.setData(pageInfo);
		return pageInfoResponse;
	}
	

	/* (non-Javadoc)
	 * @see com.ycxc.vmts.service.DmpRolePermissionService#add(com.ycxc.vmts.entity.DmpRolePermission, javax.servlet.http.HttpServletRequest)
	 */
	@Override
	@Transactional(rollbackFor=Exception.class)
	public BaseBeanResponse<DmpRolePermission> add(DmpRolePermission dmpRolePermission, HttpServletRequest httpRequest) throws Exception {
		BaseBeanResponse<DmpRolePermission> baseBeanResponse = new BaseBeanResponse<>();
		
		dmpRolePermissionMapper.insertSelective(dmpRolePermission);
		
		baseBeanResponse.setCode(ResultCode.SUCCESS.val());
		baseBeanResponse.setMessage("新增成功");
		baseBeanResponse.setData(dmpRolePermission);
		
		return baseBeanResponse;
	}

	/* (non-Javadoc)
	 * @see com.ycxc.vmts.service.DmpRolePermissionService#edit(com.ycxc.vmts.entity.DmpRolePermission, javax.servlet.http.HttpServletRequest)
	 */
	@Override
	@Transactional(rollbackFor=Exception.class)
	public BaseBeanResponse<DmpRolePermission> edit(DmpRolePermission dmpRolePermission, HttpServletRequest httpRequest) throws Exception {
		BaseBeanResponse<DmpRolePermission> baseBeanResponse = new BaseBeanResponse<>();
		
		dmpRolePermissionMapper.updateByPrimaryKeySelective(dmpRolePermission);
		
		baseBeanResponse.setCode(ResultCode.SUCCESS.val());
		baseBeanResponse.setMessage("修改成功");
		baseBeanResponse.setData(dmpRolePermission);
		
		return baseBeanResponse;
	}

	/* (non-Javadoc)
	 * @see com.ycxc.vmts.service.DmpRolePermissionService#findById(com.ycxc.vmts.controller.bean.DmpRolePermissionRequest, javax.servlet.http.HttpServletRequest)
	 */
	@Override
	public BaseBeanResponse<DmpRolePermissionDto> findById(DmpRolePermissionRequest dmpRolePermissionRequest, HttpServletRequest httpRequest)
			throws Exception {
		BaseBeanResponse<DmpRolePermissionDto> baseBeanResponse = new BaseBeanResponse<>();
		
		DmpRolePermissionDto dmpRolePermissionDto = dmpRolePermissionMapper.findById(dmpRolePermissionRequest.getRolePermissionId());
		
		baseBeanResponse.setCode(ResultCode.SUCCESS.val());
		baseBeanResponse.setMessage("查询成功");
		baseBeanResponse.setData(dmpRolePermissionDto);
		
		return baseBeanResponse;
	}

	/* (non-Javadoc)
	 * @see com.ycxc.vmts.service.DmpRolePermissionService#deleteById(com.ycxc.vmts.controller.bean.DmpRolePermissionRequest, javax.servlet.http.HttpServletRequest)
	 */
	@Override
	@Transactional(rollbackFor=Exception.class)
	public BaseResponse deleteById(DmpRolePermissionRequest dmpRolePermissionRequest, HttpServletRequest httpRequest)
			throws Exception {
		BaseResponse baseResponse = new BaseResponse();
		
		dmpRolePermissionMapper.deleteByPrimaryKey(dmpRolePermissionRequest.getRolePermissionId());
		
		baseResponse.setCode(ResultCode.SUCCESS.val());
		baseResponse.setMessage("删除成功");
		
		return baseResponse;
	}

	/* (non-Javadoc)
	 * @see com.ycxc.vmts.service.DmpRolePermissionService#addBatch(com.ycxc.vmts.controller.bean.DmpRolePermissionVo, javax.servlet.http.HttpServletRequest)
	 */
	@Override
	@Transactional(rollbackFor=Exception.class)
	public BaseBeanResponse<DmpRolePermissionBatch> addBatch(DmpRolePermissionBatch dmpRolePermissionBatch, HttpServletRequest httpRequest) throws Exception {
		BaseBeanResponse<DmpRolePermissionBatch> baseBeanResponse = new BaseBeanResponse<>();
		
		List<DmpRolePermission> dmpRolePermissions = dmpRolePermissionBatch.getDmpRolePermissions();
		
		if (CollectionUtils.isEmpty(dmpRolePermissions)) {
			baseBeanResponse.setCode(ResultCode.PARAMS_ERROR.val());
			baseBeanResponse.setMessage("数据不能为空！");
			return baseBeanResponse;
		}
		
		dmpRolePermissions = dmpRolePermissions.stream().map(dmpRolePermission -> {
			return dmpRolePermission;
		}).collect(Collectors.toList());
		
		dmpRolePermissionMapper.insertBatch(dmpRolePermissions);
		
		baseBeanResponse.setCode(ResultCode.SUCCESS.val());
		baseBeanResponse.setMessage("批量新增成功");
		baseBeanResponse.setData(dmpRolePermissionBatch);
		
		return baseBeanResponse;
	}
	
}
